package mathutil

import (
	"encoding/json"
	"testing"
	"time"

	"github.com/stretchr/testify/assert"
)

func TestToInt(t *testing.T) {
	is := assert.New(t)

	tests := []interface{}{
		2,
		int8(2), int16(2), int32(2), int64(2),
		uint(2), uint8(2), uint16(2), uint32(2), uint64(2),
		float32(2.2), 2.3,
		"2",
		time.Duration(2),
		json.Number("2"),
	}
	errTests := []interface{}{
		nil,
		"2a",
		[]int{1},
	}

	// To int
	intVal, err := Int("2")
	is.Nil(err)
	is.Equal(2, intVal)

	intVal, err = ToInt("-2")
	is.Nil(err)
	is.Equal(-2, intVal)

	intVal, err = IntOrErr("-2")
	is.Nil(err)
	is.Equal(-2, intVal)

	is.Equal(-2, MustInt("-2"))
	for _, in := range tests {
		is.Equal(2, MustInt(in))
		is.Equal(2, QuietInt(in))
	}
	for _, in := range errTests {
		is.Equal(0, MustInt(in))
	}

	// To uint
	uintVal, err := Uint("2")
	is.Nil(err)
	is.Equal(uint64(2), uintVal)

	uintVal, err = UintOrErr("2")
	is.Nil(err)
	is.Equal(uint64(2), uintVal)

	_, err = ToUint("-2")
	is.Error(err)

	is.Equal(uint64(0), MustUint("-2"))
	for _, in := range tests {
		is.Equal(uint64(2), MustUint(in))
	}
	for _, in := range errTests {
		is.Equal(uint64(0), QuietUint(in))
		is.Equal(uint64(0), MustUint(in))
	}

	// To int64
	i64Val, err := ToInt64("2")
	is.Nil(err)
	is.Equal(int64(2), i64Val)

	i64Val, err = Int64("-2")
	is.Nil(err)
	is.Equal(int64(-2), i64Val)

	i64Val, err = Int64OrErr("-2")
	is.Nil(err)
	is.Equal(int64(-2), i64Val)

	for _, in := range tests {
		is.Equal(int64(2), MustInt64(in))
	}
	for _, in := range errTests {
		is.Equal(int64(0), MustInt64(in))
		is.Equal(int64(0), QuietInt64(in))
	}
}

func TestToString(t *testing.T) {
	is := assert.New(t)

	tests := []interface{}{
		2,
		int8(2), int16(2), int32(2), int64(2),
		uint(2), uint8(2), uint16(2), uint32(2), uint64(2),
		float32(2), float64(2),
		// "2",
		time.Duration(2),
		json.Number("2"),
	}

	for _, in := range tests {
		is.Equal("2", String(in))
		is.Equal("2", QuietString(in))
		is.Equal("2", MustString(in))
		val, err := ToString(in)
		is.NoError(err)
		is.Equal("2", val)
	}

	val, err := StringOrErr(2)
	is.NoError(err)
	is.Equal("2", val)

	is.Panics(func() {
		MustString("2")
	})
}

func TestToFloat(t *testing.T) {
	is := assert.New(t)

	tests := []interface{}{
		2,
		int8(2), int16(2), int32(2), int64(2),
		uint(2), uint8(2), uint16(2), uint32(2), uint64(2),
		float32(2), float64(2),
		"2",
		time.Duration(2),
		json.Number("2"),
	}
	for _, in := range tests {
		is.Equal(float64(2), MustFloat(in))
	}

	is.Equal(123.5, MustFloat("123.5"))
	is.Equal(123.5, QuietFloat("123.5"))
	is.Equal(float64(0), MustFloat("invalid"))
	is.Equal(float64(0), QuietFloat("invalid"))

	fltVal, err := ToFloat("123.5")
	is.Nil(err)
	is.Equal(123.5, fltVal)

	fltVal, err = Float("-123.5")
	is.Nil(err)
	is.Equal(-123.5, fltVal)

	fltVal, err = FloatOrErr("-123.5")
	is.Nil(err)
	is.Equal(-123.5, fltVal)
}
